@@ -11,7 +11,7 @@
 
 raise "sorry, 1.8 was last decade" unless RUBY_VERSION >= '1.9'
 
-gem 'kramdown', '~> 1.16.0'
+gem 'kramdown', '~> 1.17.0'
 require 'kramdown'
 my_span_elements =  %w{list figure xref eref iref cref spanx vspace}
 Kramdown::Parser::Html::Constants::HTML_SPAN_ELEMENTS.concat my_span_elements
@@ -483,7 +483,7 @@ module Kramdown
         "CCITT" => "bibxml2",
         "FIPS" => "bibxml2",
         # "IANA" => "bibxml2",   overtaken by bibxml8
-        "IEEE" => "bibxml2",    # now, how about bibxml6?
+        "IEEE" => "bibxml6",    # copied over to bibxml6 2019-02-27
         "ISO" => "bibxml2",
         "ITU" => "bibxml2",
         "NIST" => "bibxml2",
@@ -519,10 +519,14 @@ module Kramdown
           to_insert = ""
           src.scan(/(W3C|3GPP|[A-Z-]+)[.]?([A-Za-z_0-9.\/\+-]+)/) do |t, n|
             fn = "reference.#{t}.#{n}.xml"
-            sub, ttl = XML_RESOURCE_ORG_MAP[t]
+            sub, ttl, can_anchor = XML_RESOURCE_ORG_MAP[t]
             ttl ||= KRAMDOWN_REFCACHETTL  # everything but RFCs might change a lot
             puts "Huh: ${fn}" unless sub
             url = "#{XML_RESOURCE_ORG_PREFIX}/#{sub}/#{fn}"
+            if can_anchor # create anchor server-side for stand_alone: false
+              url << "?anchor=#{anchor}"
+              fn[/.xml$/] = "--anchor=#{anchor}.xml"
+            end
             to_insert = get_and_cache_resource(url, fn.gsub('/', '_'), ttl)
             to_insert.scrub! rescue nil # only do this for Ruby >= 2.1
             # this may be a bit controversial: Don't break the build if reference is broken
